==> xmms-alarm_0.3.0-pre2.1.tar.gz: xmms-alarm-0.3.0/src/callbacks.c <==
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gtk/gtk.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"


void
alarm_current_volume                   (GtkButton       *button,
                                        gpointer         user_data)
{

}


void
alarm_save                             (GtkButton       *button,
                                        gpointer         user_data)
{

}


void
alarm_stop_cancel                      (GtkButton       *button,
                                        gpointer         user_data)
{

}


void
alarm_store_playlistname               (GtkButton       *button,
                                        gpointer         user_data)
{

}


void
on_mon_def_toggled                     (GtkToggleButton *togglebutton,
                                        gpointer         user_data)
{
   extern GtkWidget *mon_h;

   gtk_widget_set_sensitive(mon_h, FALSE);

}


void
on_tue_def_toggled                     (GtkToggleButton *togglebutton,
                                        gpointer         user_data)
{

}


void
on_wed_def_toggled                     (GtkToggleButton *togglebutton,
                                        gpointer         user_data)
{

}


void
on_thu_def_toggled                     (GtkToggleButton *togglebutton,
                                        gpointer         user_data)
{

}


void
on_fri_def_toggled                     (GtkToggleButton *togglebutton,
                                        gpointer         user_data)
{

}


void
on_sat_def_toggled                     (GtkToggleButton *togglebutton,
                                        gpointer         user_data)
{

}


void
on_sun_def_toggled                     (GtkToggleButton *togglebutton,
                                        gpointer         user_data)
{

}

==> xmms-alarm_0.3.7.orig.tar.gz: xmms-alarm-0.3.7/src/callbacks.c <==
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gtk/gtk.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"


void
alarm_current_volume                   (GtkButton       *button,
                                        gpointer         user_data)
{

}


void
alarm_save                             (GtkButton       *button,
                                        gpointer         user_data)
{

}


void
alarm_stop_cancel                      (GtkButton       *button,
                                        gpointer         user_data)
{

}


void
alarm_store_playlistname               (GtkButton       *button,
                                        gpointer         user_data)
{

}


void
on_mon_def_toggled                     (GtkToggleButton *togglebutton,
                                        gpointer         user_data)
{

}


void
on_tue_def_toggled                     (GtkToggleButton *togglebutton,
                                        gpointer         user_data)
{

}


void
on_wed_def_toggled                     (GtkToggleButton *togglebutton,
                                        gpointer         user_data)
{

}


void
on_thu_def_toggled                     (GtkToggleButton *togglebutton,
                                        gpointer         user_data)
{

}


void
on_fri_def_toggled                     (GtkToggleButton *togglebutton,
                                        gpointer         user_data)
{

}


void
on_sat_def_toggled                     (GtkToggleButton *togglebutton,
                                        gpointer         user_data)
{

}


void
on_sun_def_toggled                     (GtkToggleButton *togglebutton,
                                        gpointer         user_data)
{

}

/*
 * vi:ai:expandtab:ts=2 sts=2 shiftwidth=2:nowrap:
 */
